@@ -1,39 +1,37 @@
 import struct
 
 
-class SSTPPacket(object):
-    _version = '\x10'
+class SSTPPacket:
+    _version = 0x10
 
-    def __init__(self, c, data=''):
-        self.c = c
+    def __init__(self, c, data=b''):
+        self.c = c & 0x01
         self.data = data
 
 
-    def dump(self):
-        length = struct.pack('!H', len(self.data) + 4)
-        c = chr(self.c & 0x01)
-        return self._version + c + length + self.data
+    def write_to(self, func):
+        func(struct.pack('!BBH', self._version, self.c, len(self.data) + 4))
+        func(self.data)
 
 
 class SSTPDataPacket(SSTPPacket):
 
     def __init__(self, data):
-        super(SSTPDataPacket, self).__init__(0, data)
+        super().__init__(0, data)
 
 
 class SSTPControlPacket(SSTPPacket):
 
     def __init__(self, message_type, attributes=[]):
-        super(SSTPControlPacket, self).__init__(1)
+        super().__init__(1)
         self.message_type = message_type
         self.attributes = attributes
 
-
-    def dump(self):
+    def write_to(self, func):
         num_attribute = struct.pack('!H', len(self.attributes))
         self.data = self.message_type + num_attribute
         for attr_id, attr_value in self.attributes:
             length = struct.pack('!H', len(attr_value) + 4)
-            self.data += '\x00' + attr_id + length + attr_value 
-        return super(SSTPControlPacket, self).dump()
+            self.data += b'\x00' + attr_id + length + attr_value
+        return super().write_to(func)
 
